(function () {
  var enterModule = require('react-hot-loader').enterModule;

  enterModule && enterModule(module);
})();

import T from 'i18n-react';
import 'redux-thunk';

import '../../dataset/reducer';
import { defaultSuccess, defaultError } from '../../common/actions';
import api from '../../api';
import { QUERY_AGAIN_TIMEOUT } from '../../query-runner/constants';
import { getStoredQuery } from '../../api/api';

import { loadPreviousQueries } from '../list/actions';

import { OPEN_UPLOAD_MODAL, CLOSE_UPLOAD_MODAL, UPLOAD_FILE_START, UPLOAD_FILE_SUCCESS, UPLOAD_FILE_ERROR } from './actionTypes';

export var openUploadModal = function openUploadModal() {
  return {
    type: OPEN_UPLOAD_MODAL
  };
};

export var closeUploadModal = function closeUploadModal() {
  return {
    type: CLOSE_UPLOAD_MODAL
  };
};

export var uploadFileStart = function uploadFileStart() {
  return { type: UPLOAD_FILE_START };
};
export var uploadFileSuccess = function uploadFileSuccess(success) {
  return defaultSuccess(UPLOAD_FILE_SUCCESS, success);
};
export var uploadFileError = function uploadFileError(error, payload) {
  return defaultError(UPLOAD_FILE_ERROR, error, {
    successful: payload.successful,
    unsuccessful: payload.unsuccessful
  });
};

export var uploadFile = function uploadFile(datasetId, file) {
  return function (dispatch) {
    dispatch(uploadFileStart());

    return api.postResults(datasetId, file).then(function (r) {
      if (r.status === 'RUNNING' || r.status === 'NEW') dispatch(waitForQueryDone(datasetId, r.id));

      if (r.status === 'FAILED' || r.status === 'CANCELED') dispatch(uploadFailed(r));

      if (r.status === 'DONE') dispatch([uploadFileSuccess(r), loadPreviousQueries(datasetId)]);
    }, function (e) {
      return dispatch(uploadFailed(e));
    });
  };
};

var uploadFailed = function uploadFailed(result) {
  return uploadFileError({
    message: T.translate('uploadQueryResultsModal.uploadFailed')
  }, result);
};

var waitForQueryDone = function waitForQueryDone(datasetId, queryId) {
  return function (dispatch) {
    return getStoredQuery(datasetId, queryId).then(function (r) {
      if (r.status === 'DONE' && r.message) return dispatch(uploadFailed(r));else if (r.status === 'DONE') return dispatch([uploadFileSuccess(r), loadPreviousQueries(datasetId)]);else setTimeout(function () {
        return waitForQueryDone(datasetId, queryId);
      }, QUERY_AGAIN_TIMEOUT);
    });
  };
};
;

(function () {
  var reactHotLoader = require('react-hot-loader').default;

  var leaveModule = require('react-hot-loader').leaveModule;

  if (!reactHotLoader) {
    return;
  }

  reactHotLoader.register(openUploadModal, 'openUploadModal', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/upload/actions.js');
  reactHotLoader.register(closeUploadModal, 'closeUploadModal', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/upload/actions.js');
  reactHotLoader.register(uploadFileStart, 'uploadFileStart', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/upload/actions.js');
  reactHotLoader.register(uploadFileSuccess, 'uploadFileSuccess', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/upload/actions.js');
  reactHotLoader.register(uploadFileError, 'uploadFileError', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/upload/actions.js');
  reactHotLoader.register(uploadFile, 'uploadFile', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/upload/actions.js');
  reactHotLoader.register(uploadFailed, 'uploadFailed', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/upload/actions.js');
  reactHotLoader.register(waitForQueryDone, 'waitForQueryDone', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/upload/actions.js');
  leaveModule(module);
})();

;